﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;


namespace MathExercise1
{
    public class Player
    {
        private Texture2D image;
        private World mWorld;
        private float shotCooldown = 0.0f;

        public float Max_Speed;
        public float Max_Speed_Squared;


        // Contains Position, Rotation
        private AnimatedObject playerObject;
        public Vector2 Velocity { get; set; }
        public float Rotation
        {
            get
            {
                return playerObject.Rotation;
            }
            set
            {
                playerObject.Rotation = value;
            }
        }
        public Vector2 Position
        {
            get
            {
                return playerObject.Position;
            }
            set
            {
                playerObject.Position = value;
            }
        }
        // Shipdata conttains:
        //   public Vector2 center -- vector from the upper-left of texture to center of the ship
        //                            (used as the "center" paramater for spritebatch.draw())
        //   public Vector2 facing -- unit vector facing in the direction of the ship
        //   public int maxSpeed -- maximum speed for this ship (used by World)
        //   public float acceleration -- linear acceleration for ship, in pixels / second * second
        //   public float rotationSpeed -- 
        //   public Vector2[] gunPositions -- array of vectors, giving the displacement from the
        //                                    center of the ship to the end of each gun on the ship
        private ShipData mShipdata;


        public Player(World game)
        {
            mWorld = game;
        }
        public void LoadContent(ContentManager content)
        {
            mShipdata = content.Load<ShipData>("PlayerShip");
            image = content.Load<Texture2D>(mShipdata.spriteName);
            playerObject = new AnimatedObject(image, image.Width, mShipdata.center, false, 0.1f, new Vector2(100, 100));
            Max_Speed = mShipdata.maxSpeed;
            Max_Speed_Squared = Max_Speed * Max_Speed;
        }


        private Vector2 rotate(Vector2 v, float theta)
        {
            return new Vector2((float)(v.X * Math.Cos(theta) + v.Y * Math.Sin(theta)), (float)(v.X * Math.Sin(theta) - v.Y * Math.Cos(theta)));

        }


        public void Update(GameTime gameTime)
        {

            shotCooldown = Math.Max(0, shotCooldown - (float)gameTime.ElapsedGameTime.TotalSeconds);

            KeyboardState keyboard = Keyboard.GetState();

            if (keyboard.IsKeyDown(Keys.Left))
            {
                playerObject.Rotation -= (float)gameTime.ElapsedGameTime.TotalSeconds * MathHelper.ToRadians(mShipdata.rotationSpeed);
            }
            else if (keyboard.IsKeyDown(Keys.Right))
            {
                playerObject.Rotation += (float)gameTime.ElapsedGameTime.TotalSeconds * MathHelper.ToRadians(mShipdata.rotationSpeed);
            }
            if (keyboard.IsKeyDown(Keys.Up))
            {
                // Change the velocity to move the ship!
            }
            if (keyboard.IsKeyDown(Keys.Space) && shotCooldown == 0)
            {
                shotCooldown = mShipdata.shotCooldown;
                foreach (Vector2 pos in mShipdata.gunPositions)
                {
                    // Create a projectile for each gun position, with a velocity that is pointed in
                    // the direction the ship is facing, with the proper shot velocity

                    mWorld.Projectiles.CreateProjectile(playerObject.Position, new Vector2(50,0));
                }
            }

        }
        public void Draw(SpriteBatch spriteBatch)
        {
            playerObject.Draw(spriteBatch);
        }

    }
}
